searchData={"items":[{"type":"module","title":"Soleil","doc":"The official support library for the [Soleil](https://protolux.io/soleil) power\nmanagement and sleep control board for Raspberry Pi.\n\nThis library provides functions for managing device power, scheduling sleep \ndurations and wake times, as well as reading battery information. It is designed \nto abstract low-level hardware interactions, providing a clean and intuitive API \nfor developers.","ref":"Soleil.html"},{"type":"function","title":"Soleil.battery_info/0","doc":"Reads battery information from the hardware.\n\nThis function queries the battery for its state of charge, voltage, \naverage current consumption, and temperature.","ref":"Soleil.html#battery_info/0"},{"type":"function","title":"Examples - Soleil.battery_info/0","doc":"iex> {:ok, info} = Soleil.battery_info()\n    iex> Map.keys(info)\n    [:state_of_charge, :voltage, :current, :temperature]","ref":"Soleil.html#battery_info/0-examples"},{"type":"function","title":"Soleil.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Soleil.html#child_spec/1"},{"type":"function","title":"Soleil.configure_fuel_gauge/1","doc":"Updates the configuration of the BQ27427 battery fuel gauge chip.\n\nAccepts the same parameters as `start_link/1`.","ref":"Soleil.html#configure_fuel_gauge/1"},{"type":"function","title":"Examples - Soleil.configure_fuel_gauge/1","doc":"iex> Soleil.configure_fuel_gauge(battery_capacity: 1000, battery_energy: 3700)\n    :ok","ref":"Soleil.html#configure_fuel_gauge/1-examples"},{"type":"function","title":"Soleil.init/1","doc":"","ref":"Soleil.html#init/1"},{"type":"function","title":"Soleil.power_off/0","doc":"Powers off the device.\n\nOn supported hardware, this will initiate a shutdown sequence. On host \nenvironments (e.g., during development), it simulates the power-off behavior.","ref":"Soleil.html#power_off/0"},{"type":"function","title":"Examples - Soleil.power_off/0","doc":"iex> :ok = Soleil.power_off()","ref":"Soleil.html#power_off/0-examples"},{"type":"function","title":"Soleil.sleep_for/2","doc":"Puts the device to sleep for a specified duration.\n\nThe device will enter a low-power state and wake up after the specified duration.","ref":"Soleil.html#sleep_for/2"},{"type":"function","title":"Parameters - Soleil.sleep_for/2","doc":"- `duration` - The duration to sleep.\n- `unit` - the unit of duration.","ref":"Soleil.html#sleep_for/2-parameters"},{"type":"function","title":"Examples - Soleil.sleep_for/2","doc":"iex> Soleil.sleep_for(60) # Sleep for 1 minute\n    :ok","ref":"Soleil.html#sleep_for/2-examples"},{"type":"function","title":"Soleil.sleep_until/1","doc":"Puts the device to sleep until a specified datetime.\n\nThe device will enter a low-power state and wake up at the specified time.","ref":"Soleil.html#sleep_until/1"},{"type":"function","title":"Parameters - Soleil.sleep_until/1","doc":"- `datetime` - A UTC `NaiveDateTime` representing the target wake-up time.","ref":"Soleil.html#sleep_until/1-parameters"},{"type":"function","title":"Examples - Soleil.sleep_until/1","doc":"iex> :ok = Soleil.sleep_until(~N[2024-11-17 08:30:00])","ref":"Soleil.html#sleep_until/1-examples"},{"type":"function","title":"Soleil.start_link/1","doc":"Starts the Soleil GenServer process.\n\nThis function initializes the state and prepares the library for use.","ref":"Soleil.html#start_link/1"},{"type":"function","title":"Options - Soleil.start_link/1","doc":"- `:i2c_bus` - The I2C bus to use for hardware communication (default: `\"i2c-1\"`).\n- `:battery_capacity` - The rated battery capacity in mAh (default: 2000).\n- `:battery_energy` - The rated battery power in mWh (default: 7400).","ref":"Soleil.html#start_link/1-options"},{"type":"function","title":"Examples - Soleil.start_link/1","doc":"iex> {:ok, pid} = Soleil.start_link(battery_capacity: 1000, battery_energy: 3700)\n    iex> is_pid(pid)\n    true","ref":"Soleil.html#start_link/1-examples"},{"type":"function","title":"Soleil.wakeup_reason/0","doc":"Reports the reason that the board woke from sleep.\n\nReasons for wakeup include:\n- `:alarm`: when the RTC alarm triggers wakeup, such as after `sleep_for/2` or `sleep_until/1`\n- `:manual`: when the pushbutton or hall sensor triggers wakeup","ref":"Soleil.html#wakeup_reason/0"},{"type":"function","title":"Examples - Soleil.wakeup_reason/0","doc":"iex> Soleil.wakeup_reason()\n    :manual","ref":"Soleil.html#wakeup_reason/0-examples"},{"type":"type","title":"Soleil.battery_info/0","doc":"","ref":"Soleil.html#t:battery_info/0"},{"type":"module","title":"Soleil.BQ27427","doc":"Driver for the Texas Instruments BQ27427 Battery Fuel Gauge.\n\nThis module provides a complete interface to the BQ27427 fuel gauge, including:\n- Battery measurements (voltage, current, power)\n- State of charge and capacity readings\n- Temperature measurements\n- Status flags and control operations\n- Configuration mode management","ref":"Soleil.BQ27427.html"},{"type":"function","title":"Soleil.BQ27427.chemistry_id/1","doc":"Get the chemical ID of the battery profile.","ref":"Soleil.BQ27427.html#chemistry_id/1"},{"type":"function","title":"Examples - Soleil.BQ27427.chemistry_id/1","doc":"iex> {:ok, ref} = Circuits.I2C.open(\"i2c-1\")\n    iex> Soleil.BQ27427.chemistry_id(ref)\n    {:ok, :chemistry_b} # using chemistry B for SOC algorithm","ref":"Soleil.BQ27427.html#chemistry_id/1-examples"},{"type":"function","title":"Soleil.BQ27427.configure_soc1_interrupt/3","doc":"Configures the GPOUT pin as a State of Charge interrupt with the given threshold.","ref":"Soleil.BQ27427.html#configure_soc1_interrupt/3"},{"type":"function","title":"Parameters - Soleil.BQ27427.configure_soc1_interrupt/3","doc":"- threshold: Percentage (0-100) at which to trigger the interrupt\n  - clear_threshold: Percentage (0-100) at which to clear the interrupt","ref":"Soleil.BQ27427.html#configure_soc1_interrupt/3-parameters"},{"type":"function","title":"Example - Soleil.BQ27427.configure_soc1_interrupt/3","doc":"iex> Soleil.BQ27427.configure_soc1_interrupt(i2c, 20, 25)  # Trigger at 20%, clear at 25%","ref":"Soleil.BQ27427.html#configure_soc1_interrupt/3-example"},{"type":"function","title":"Soleil.BQ27427.control_status/1","doc":"Get control status as a map.","ref":"Soleil.BQ27427.html#control_status/1"},{"type":"function","title":"Examples - Soleil.BQ27427.control_status/1","doc":"iex> {:ok, ref} = Circuits.I2C.open(\"i2c-1\")\n    iex> Soleil.BQ27427.control_status(ref)\n    {:ok, %{\n      sleep: false,\n      bca: false,\n      calmode: false,\n      cca: false,\n      chemchange: false,\n      initcomp: true,\n      ldmd: true,\n      qmax_up: false,\n      res_up: false,\n      rup_dis: true,\n      sealed: false,\n      shutdown_enabled: false,\n      vok: false,\n      wdreset: false\n    }}","ref":"Soleil.BQ27427.html#control_status/1-examples"},{"type":"function","title":"Soleil.BQ27427.current/1","doc":"Get the average current in amps. Positive values indicate charging,\nnegative values indicate discharging.","ref":"Soleil.BQ27427.html#current/1"},{"type":"function","title":"Examples - Soleil.BQ27427.current/1","doc":"iex> {:ok, ref} = Circuits.I2C.open(\"i2c-1\")\n    iex> Soleil.BQ27427.current(ref)\n    {:ok, -0.250} # Discharging at 250mA","ref":"Soleil.BQ27427.html#current/1-examples"},{"type":"function","title":"Soleil.BQ27427.enter_config_mode/1","doc":"Enter configuration mode. The device must be unsealed before this can be used.","ref":"Soleil.BQ27427.html#enter_config_mode/1"},{"type":"function","title":"Soleil.BQ27427.flags/1","doc":"Get all status flags as a map.","ref":"Soleil.BQ27427.html#flags/1"},{"type":"function","title":"Examples - Soleil.BQ27427.flags/1","doc":"iex> {:ok, ref} = Circuits.I2C.open(\"i2c-1\")\n    iex> Soleil.BQ27427.flags(ref)\n    {:ok, %{\n      over_temp_flag: false,\n      under_temp_flag: false,\n      full_charge: false,\n      charging: true,\n      ocv_taken: true,\n      dod_correct: true,\n      itpor: false,\n      cfgupmode: false,\n      bat_det: true,\n      soc1: false,\n      socf: false,\n      discharging: true\n    }}","ref":"Soleil.BQ27427.html#flags/1-examples"},{"type":"function","title":"Soleil.BQ27427.full_charge_capacity/1","doc":"Get the full charge capacity in mAh.","ref":"Soleil.BQ27427.html#full_charge_capacity/1"},{"type":"function","title":"Examples - Soleil.BQ27427.full_charge_capacity/1","doc":"iex> {:ok, ref} = Circuits.I2C.open(\"i2c-1\")\n    iex> Soleil.BQ27427.full_charge_capacity(ref)\n    {:ok, 1980} # battery has an estimated capacity of 1980mAh at full charge","ref":"Soleil.BQ27427.html#full_charge_capacity/1-examples"},{"type":"function","title":"Soleil.BQ27427.get_design_capacity/1","doc":"Gets the design capacity of the battery in mAh. The device must be unsealed\nto use this function","ref":"Soleil.BQ27427.html#get_design_capacity/1"},{"type":"function","title":"Example - Soleil.BQ27427.get_design_capacity/1","doc":"iex> Soleil.BQ27427.get_design_capacity(i2c)\n    {:ok, 1200} # 1200 mAh battery","ref":"Soleil.BQ27427.html#get_design_capacity/1-example"},{"type":"function","title":"Soleil.BQ27427.get_design_energy/1","doc":"Gets the design capacity of the battery in mWh. The device must be unsealed\nto use this function","ref":"Soleil.BQ27427.html#get_design_energy/1"},{"type":"function","title":"Example - Soleil.BQ27427.get_design_energy/1","doc":"iex> Soleil.BQ27427.get_design_energy(i2c)\n    {:ok, 3000} # 3000 mWh battery","ref":"Soleil.BQ27427.html#get_design_energy/1-example"},{"type":"function","title":"Soleil.BQ27427.power/1","doc":"Get the average power in watts. Positive values indicate charging,\nnegative values indicate discharging.","ref":"Soleil.BQ27427.html#power/1"},{"type":"function","title":"Examples - Soleil.BQ27427.power/1","doc":"iex> {:ok, ref} = Circuits.I2C.open(\"i2c-1\")\n    iex> Soleil.BQ27427.current(ref)\n    {:ok, -0.850} # Discharging at 850mW","ref":"Soleil.BQ27427.html#power/1-examples"},{"type":"function","title":"Soleil.BQ27427.read_data_memory/5","doc":"","ref":"Soleil.BQ27427.html#read_data_memory/5"},{"type":"function","title":"Soleil.BQ27427.remaining_capacity/1","doc":"Get the remaining capacity in mAh.","ref":"Soleil.BQ27427.html#remaining_capacity/1"},{"type":"function","title":"Examples - Soleil.BQ27427.remaining_capacity/1","doc":"iex> {:ok, ref} = Circuits.I2C.open(\"i2c-1\")\n    iex> Soleil.BQ27427.remaining_capacity(ref)\n    {:ok, 1128} # battery has an estimated 1128mAh remaining","ref":"Soleil.BQ27427.html#remaining_capacity/1-examples"},{"type":"function","title":"Soleil.BQ27427.reset/1","doc":"Perform a hard reset of the device. This will reset all registers to their default values.","ref":"Soleil.BQ27427.html#reset/1"},{"type":"function","title":"Soleil.BQ27427.seal/1","doc":"Seal the device to prevent configuration changes.","ref":"Soleil.BQ27427.html#seal/1"},{"type":"function","title":"Soleil.BQ27427.set_charge_direction/1","doc":"Sets the bit to configure sign of the CC_Gain parameter. The default firmware for\nthe BQ27427 for some reason shipped with the wrong value, and isn't documented in\nthe datasheet. See the TI support issue for more information:\n\nhttps://e2e.ti.com/support/power-management-group/power-management/f/power-management-forum/1215460/bq27427evm-misbehaving-stateofcharge","ref":"Soleil.BQ27427.html#set_charge_direction/1"},{"type":"function","title":"Example - Soleil.BQ27427.set_charge_direction/1","doc":"iex> Soleil.BQ27427.set_charge_direction(i2c)\n    :ok","ref":"Soleil.BQ27427.html#set_charge_direction/1-example"},{"type":"function","title":"Soleil.BQ27427.set_chemistry_id/2","doc":"Sets the chemistry ID of the battery profile. The device must be unsealed\nto use this function","ref":"Soleil.BQ27427.html#set_chemistry_id/2"},{"type":"function","title":"Example - Soleil.BQ27427.set_chemistry_id/2","doc":"iex> {:ok, i2c} = Circuits.I2C.open(\"i2c-1\")\n    iex> Soleil.BQ27427.set_chemistry_id(i2c, :chemistry_a)\n    :ok","ref":"Soleil.BQ27427.html#set_chemistry_id/2-example"},{"type":"function","title":"Soleil.BQ27427.set_design_capacity/2","doc":"Sets the design capacity of the battery in mAh. The device must be unsealed\nto use this function","ref":"Soleil.BQ27427.html#set_design_capacity/2"},{"type":"function","title":"Example - Soleil.BQ27427.set_design_capacity/2","doc":"iex> Soleil.BQ27427.set_design_capacity(i2c, 1200)  # 1200mAh battery","ref":"Soleil.BQ27427.html#set_design_capacity/2-example"},{"type":"function","title":"Soleil.BQ27427.set_design_energy/2","doc":"Sets the design energy of the battery in mWh. The device must be unsealed\nto use this function","ref":"Soleil.BQ27427.html#set_design_energy/2"},{"type":"function","title":"Example - Soleil.BQ27427.set_design_energy/2","doc":"iex> Soleil.BQ27427.set_design_energy(i2c, 4440)  # 4440mWh battery","ref":"Soleil.BQ27427.html#set_design_energy/2-example"},{"type":"function","title":"Soleil.BQ27427.soft_reset/1","doc":"Perform a soft reset of the device. This maintains configuration but resets calculations.\nUsed to exit configuration mode (has the side effect of re-sealing the device)","ref":"Soleil.BQ27427.html#soft_reset/1"},{"type":"function","title":"Soleil.BQ27427.state_of_charge/1","doc":"Get the state of charge as a percentage (0-100).","ref":"Soleil.BQ27427.html#state_of_charge/1"},{"type":"function","title":"Examples - Soleil.BQ27427.state_of_charge/1","doc":"iex> {:ok, ref} = Circuits.I2C.open(\"i2c-1\")\n    iex> Soleil.BQ27427.state_of_charge(ref)\n    {:ok, 37} # battery is at 37%","ref":"Soleil.BQ27427.html#state_of_charge/1-examples"},{"type":"function","title":"Soleil.BQ27427.temperature/1","doc":"Get the internal chip temperature in degrees Celsius. Future versions\nof hardware may support reading temperature from the battery internal\nNTC sensor.","ref":"Soleil.BQ27427.html#temperature/1"},{"type":"function","title":"Examples - Soleil.BQ27427.temperature/1","doc":"iex> {:ok, ref} = Circuits.I2C.open(\"i2c-1\")\n    iex> Soleil.BQ27427.temperature(ref)\n    {:ok, 25.7} # chip temperature is  25.7C","ref":"Soleil.BQ27427.html#temperature/1-examples"},{"type":"function","title":"Soleil.BQ27427.unseal/1","doc":"Unseal the device to allow configuration changes.","ref":"Soleil.BQ27427.html#unseal/1"},{"type":"function","title":"Soleil.BQ27427.voltage/1","doc":"Gets the battery voltage in volts.","ref":"Soleil.BQ27427.html#voltage/1"},{"type":"function","title":"Examples - Soleil.BQ27427.voltage/1","doc":"iex> {:ok, ref} = Circuits.I2C.open(\"i2c-1\")\n    iex> Soleil.BQ27427.voltage(ref)\n    {:ok, 3.750}","ref":"Soleil.BQ27427.html#voltage/1-examples"},{"type":"type","title":"Soleil.BQ27427.chem_id/0","doc":"The battery chemistry type. According to the datasheet, the types correspond to \nthe following battery properties:\n\n`:chemistry_a`: 4.35 V\n`:chemistry_b`: 4.2  V\n`:chemistry_c`: 4.4  V\n\nNote: `:chemistry_b` corresponds to LiPo batteries, which is the only battery \nchemistry supported by the battery charger in the Soleil board. Future versions \nmay allow for use with other battery chemistries","ref":"Soleil.BQ27427.html#t:chem_id/0"},{"type":"type","title":"Soleil.BQ27427.i2c_bus/0","doc":"","ref":"Soleil.BQ27427.html#t:i2c_bus/0"},{"type":"module","title":"Soleil.MCP7940","doc":"Microchip MCP7940 RTC implementation for NervesTime.\n\nTo configure NervesTime to use this module, update the `:nerves_time` application\nenvironment like this:\n\n```elixir\nconfig :nerves_time, rtc: Soleil.MCP7940\n```\n\nCheck the logs for error message if the RTC doesn't appear to work.\n\nSee [the datasheet](https://ww1.microchip.com/downloads/en/devicedoc/20005010f.pdf)\nfor implementation details","ref":"Soleil.MCP7940.html"},{"type":"function","title":"Soleil.MCP7940.alarm_enabled?/1","doc":"","ref":"Soleil.MCP7940.html#alarm_enabled?/1"},{"type":"function","title":"Soleil.MCP7940.alarm_flag?/1","doc":"","ref":"Soleil.MCP7940.html#alarm_flag?/1"},{"type":"function","title":"Soleil.MCP7940.clear_alarm/1","doc":"","ref":"Soleil.MCP7940.html#clear_alarm/1"},{"type":"function","title":"Soleil.MCP7940.get_alarm/1","doc":"","ref":"Soleil.MCP7940.html#get_alarm/1"},{"type":"function","title":"Soleil.MCP7940.read_time/1","doc":"","ref":"Soleil.MCP7940.html#read_time/1"},{"type":"function","title":"Soleil.MCP7940.set_alarm/2","doc":"","ref":"Soleil.MCP7940.html#set_alarm/2"},{"type":"function","title":"Soleil.MCP7940.set_alarm_enabled/2","doc":"","ref":"Soleil.MCP7940.html#set_alarm_enabled/2"},{"type":"function","title":"Soleil.MCP7940.write_time/2","doc":"","ref":"Soleil.MCP7940.html#write_time/2"},{"type":"extras","title":"Introduction","doc":"# Introduction\n\n[Soleil](https://protolux.io/soleil) is an open source power management and sleep control board for Raspberry Pi, built with Nerves in mind. It features:\n\n- Power from lithium polymer (LiPo) battery\n- Battery charging from USB-C or solar (up to 16V)\n- Low power sleep mode with multiple wakeup sources\n\t- Real-time clock\n\t- Hall-effect switch\n\t- Pushbutton\n- NervesKey (ATECC608A) for connection with NervesHub\n- Qwiic connector to support easy connection to third-party sensors, screens and actuators\n\nIt is also highly customizable, with a permissive license and dedicated space on the board to add your custom circuitry.\n\n![Soleil board mounted on a Raspberry Pi Zero 2W](https://github.com/protolux-electronics/soleil_hardware/raw/main/docs/images/soleil.jpg)","ref":"introduction.html"},{"type":"extras","title":"Getting Started","doc":"# Getting Started\n\nTo get started building your application with Soleil, you need to have a Raspberry Pi and the Soleil hardware. A Raspberry Pi Zero 2W is recommended as it is the most power efficient of the product line, but any Raspberry Pi-compatible board will do. A pre-build Nerves system is available for the Raspberry Pi Zero 2W.","ref":"getting_started.html"},{"type":"extras","title":"Mounting the board - Getting Started","doc":"The top face of Soleil is the side with the connectors and chips. The Raspberry Pi headers insert from the bottom, through the holes in the bottom of the board. See the below reference image:\n\n![Mounting your Soleil board on a Raspberry Pi](https://github.com/protolux-electronics/soleil_hardware/raw/main/docs/images/soleil.jpg)\n\n> #### Check the mounting orientation {: .warning}\n> Mounting the board upside down may damage your Raspberry Pi, so please ensure the correct orientation before applying any power source!","ref":"getting_started.html#mounting-the-board"},{"type":"extras","title":"Battery and Solar Panel Selection - Getting Started","doc":"Soleil is designed to be compatible with [LiPo batteries from Adafruit](https://www.adafruit.com/category/574). While other vendors will have compatible batteries, Adafruit maintains a high-quality product lineup and is widely available. If using batteries sourced from another vendor, ensure that the batteries have a 2-pin JST PH connector with the positive terminal on the left (pin 1). Other battery chemistries (such as NiMH, NiCad, or LiFePO4) are NOT supported - only standard 3.7V lithium polymer batteries.\n\nDifferent sized batteries have different capabilities when it comes to charging and discharging rates. We recommend a battery with a capacity of at least 1000mAh and a C rating of at least 1C. \n\nFor solar panels, any panels up to 16V are supported. Do note that the battery charger chip does not start charging until the voltages reaches 4V. For a 6V solar panel, this means that slow charging will likely not occur in overcast or shaded conditions, and can only happen while exposed to direct sunlight. Connected multiple panels in parallel can alleviate this issue, but it is important to stress that the rated open-circuit voltage of your panels should not exceed 16V.\n\n> #### Our recommendation {: .info}\n> We like the panels from [Voltaic Systems](https://voltaicsystems.com) as they are high quality and weather-resistant.","ref":"getting_started.html#battery-and-solar-panel-selection"},{"type":"extras","title":"Nerves System - Getting Started","doc":"A prebuilt Nerves system is available for the Raspberry Pi Zero 2W. To target this system, add it and the target to your dependencies in `mix.exs`:\n\n```elixir\ndefmodule MyApp.MixProject do\n\n  # ...\n\n  @all_targets [\"...\", :soleil_rpi0_2]\n\n  # ...\n\n  defp deps do\n    [\n      # ...\n      {:soleil_system_rpi0_2, \"~> 1.28.1\", runtime: false, targets: :soleil_rpi0_2},\n      # ...\n    ]\n  end\n\n  # ...\n\nend\n```\n\nThen make sure to set the target as an environment variable:\n\n```sh\nexport MIX_TARGET=\"soleil_rpi0_2\"\n```\n\nFinally run `mix deps.get` to fetch the prebuilt system archive.","ref":"getting_started.html#nerves-system"},{"type":"extras","title":"Library Installation - Getting Started","doc":"To install and use the driver library, add it to your dependencies in `mix.exs`:\n\n```elixir\ndefmodule MyApp.MixProject do\n\n  # ...\n\n  defp deps do\n    [\n      # ...\n      {:soleil, \"~> 0.1.0\"},\n      # ...\n    ]\n  end\n\n  # ...\nend\n```\n\nThen, add `Soleil` to your supervision tree in `application.ex`:\n\n```elixir\ndefmodule MyApp.Application do\n\n  # ...\n\n  @impl true\n  def start(_type, _args) do\n    children =\n      [\n        # ...\n        {Soleil, battery_capacity: 2000, battery_energy: 7400},\n        # ...\n      ]\n\n    opts = [strategy: :one_for_one, name: SoleilDemo.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\n\n  # ...\n\nend\n```\n\n> #### Start Soleil early in the supervision tree {: .info}\n> Be sure to start `Soleil` before any other processes which might call its functions. \n\nThe parameters `battery_capacity` (in mAh) and `battery_energy` (in mWh) can be obtained from your battery's datasheet. If your battery does not have a rated energy, multiply the rated capacity by the nominal voltage (usually 3.7V for lithium polymer batteries). These parameters provide the proper information for the battery fuel gauge algorithm.","ref":"getting_started.html#library-installation"},{"type":"extras","title":"Usage - Getting Started","doc":"Soleil exposes several convenience functions for querying the state of the battery, as well as control the sleep modes. For documentation on the functions, see the `Soleil` module. For a complete usage example, see the Soleil demo project.","ref":"getting_started.html#usage"},{"type":"extras","title":"Technical Overview","doc":"# Technical Overview\n\nThis page provides a detailed overview of the hardware components that comprise Soleil. For a high-level summary, refer to the block diagram below:\n\n![Block diagram of Soleil hardware](https://github.com/protolux-electronics/soleil_hardware/raw/main/docs/images/block_diagram.png)\n\nTo understand how Soleil manages power, we will trace the flow of electricity from its sources to its consumers.","ref":"technical_overview.html"},{"type":"extras","title":"Battery Fuel Gauge - Technical Overview","doc":"The primary power source for Soleil is the battery, which operates at a voltage between 3.2V and 4.2V, depending on its state of charge. However, the relationship between voltage and the battery's energy storage is non-linear. To accurately estimate the battery's state of charge, Soleil uses the [BQ27427](https://www.ti.com/product/BQ27427) battery fuel gauge chip. This chip measures the current flowing through it using internal circuitry and calculates the battery's state of charge accordingly. \n\nThe BQ27427 communicates with the Raspberry Pi via an I2C interface, allowing it to read and write to the chip’s registers programmatically. Through the `Soleil.BQ27427` low-level driver module, users can configure battery parameters, set low-battery alarms, and perform additional tasks.","ref":"technical_overview.html#battery-fuel-gauge"},{"type":"extras","title":"Battery Charger - Technical Overview","doc":"On the other side of the battery fuel gauge is the [BQ25185](https://www.ti.com/product/BQ25185) battery charger IC. This charger features internal power path management, meaning it can simultaneously power the system load (the Raspberry Pi) and charge the battery when a power source is connected to the `V_IN` pin. \n\nWhile the chip supports various lithium battery chemistries, it is configured to charge standard LiPo batteries to 4.2V at a rate of 500mA. The `V_IN` pin can draw a maximum of 1A to handle both charging and powering the system. If the system load requires more than 1A, the charger dynamically supplements the power supply by drawing from both the input power source and the battery. The `V_SYS` output from the charger powers several downstream components, including the 5V boost converter, the low-power load switch, and the wakeup sources.","ref":"technical_overview.html#battery-charger"},{"type":"extras","title":"Boost Converter - Technical Overview","doc":"Since the Raspberry Pi requires 5V to operate and the regulated `V_SYS` voltage peaks at approximately 4V (depending on the battery's charge level), a voltage boost is necessary. The [MP3423](https://www.monolithicpower.com/en/mp3423.html) boost converter fulfills this role by increasing `V_SYS` to a steady 5V output. Additionally, the converter's `EN` pin allows the 5V output to be enabled or disabled, which is crucial for entering low-power mode via the load switch.","ref":"technical_overview.html#boost-converter"},{"type":"extras","title":"Low-Power Load Switch - Technical Overview","doc":"The [XC6192](https://product.torexsemi.com/en/series/xc6192) low-power load switch is the central control component of Soleil. It features multiple input and output pins that govern the system's power state. \n\n- The `5V_EN` output pin controls the boost converter (and, by extension, the Raspberry Pi). When `5V_EN` is low, the switch enters a low-power state to conserve battery life.  \n- The `~POWER_ON` input pin (active-low) triggers `5V_EN` to enable the 5V output when pulled low. By default, this pin is pulled high and is activated by wake-up sources.  \n- The `POWER_OFF` input pin (active-high) disables `5V_EN` when pulled high. This pin is managed by the Raspberry Pi, which sets it high during shutdown to cut off the 5V supply.","ref":"technical_overview.html#low-power-load-switch"},{"type":"extras","title":"Wakeup Sources - Technical Overview","doc":"The wake-up sources that control the `~POWER_ON` pin include a push button, the [DRV5032](https://www.ti.com/product/DRV5032) hall-effect switch, and the [MCP7940](https://www.microchip.com/en-us/product/mcp7940n) real-time clock. \n\n- When inactive, these sources allow `~POWER_ON` to remain at its default high voltage.  \n- When triggered, they pull the pin low, enabling the 5V boost converter.  \n  - The DRV5032 activates when a magnet is detected within its range.  \n  - The MCP7940 real-time clock triggers upon an alarm event.  \n\nThe MCP7940 also connects to the Raspberry Pi via I2C, allowing configuration and monitoring through the `Soleil.MCP7940` driver module.","ref":"technical_overview.html#wakeup-sources"},{"type":"extras","title":"Input Sources - Technical Overview","doc":"Soleil supports two power input sources:  \n- 5V via a USB-C connector.  \n- 6–16V via a DC input on a JST PH connector.  \n\nThe [LM66200](https://www.ti.com/product/LM66200) power multiplexer manages these inputs, ensuring that only the higher voltage source is used while blocking reverse current to the lower-voltage source. The selected input provides power to the battery charger via the `V_IN` pin.","ref":"technical_overview.html#input-sources"},{"type":"extras","title":"Source Files - Technical Overview","doc":"The source files for Soleil are available in the [GitHub repository](https://github.com/protolux-electronics/soleil_hardware). The project was designed using [KiCad](https://kicad.org), an open-source electronics design software. These files are fully customizable to meet your project requirements.\n\nA PDF of the schematic is also available for reference or [download](https://raw.githubusercontent.com/protolux-electronics/soleil_hardware/main/outputs/soleil.pdf):","ref":"technical_overview.html#source-files"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}